==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/tests/Bug_1361_Regression/run_test.pl <==
eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;

# run_test.pl,v 1.5 2003/01/29 17:10:03 bala Exp
# -*- perl -*-

use lib '../../../bin';
use PerlACE::Run_Test;
use POSIX "sys_wait_h";

$iorfile = PerlACE::LocalFile ("server$$.ior");
unlink $iorfile;

$SV = new PerlACE::Process ("server", " -o $iorfile");
$threads = int (rand() * 6) + 1;
$CL = new PerlACE::Process ("client", "-k file://$iorfile -t $threads");


$SV->Spawn ();

if (PerlACE::waitforfile_timed ($iorfile, 250) == -1) {
    print STDERR "ERROR: cannot find file <$iorfile>\n";
    $SV->Kill (); $SV->TimedWait (1);
    exit 1;
}

local $start_time = time();
local $max_running_time = 360;
local $elapsed = time() - $start_time;
my $p = $SV->{'PROCESS'};

while (($elapsed < $max_running_time) ) 
{
 # Start all clients in parallel
  $client = $CL->Spawn ();

  $CL->WaitKill(60) unless $client1 < 0;

  print STDERR "checking server alive\n";
  
  my $pid = waitpid ($SV->{PROCESS}, &WNOHANG);
  
  if ($pid != 0 && $? != -1) 
  {
    $SV->check_return_value ($?);
    $server_died = 1;
    last;
  }            

  $elapsed = time() - $start_time;
  sleep (1);
}

if (!$server_died) {
  $SH = new PerlACE::Process ("shutdown", "-k file://$iorfile");
  my $shutdown = $SH->Spawn();
  $SH->WaitKill(10) unless $shutdown < 0;

  $server = $SV->WaitKill (30);
}

if ($server != 0) {
    print STDERR "ERROR: server returned $server\n";
    $status = 1;
}

unlink $iorfile;

exit $status;

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tests/Bug_1361_Regression/run_test.pl <==
eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;

# run_test.pl,v 1.6 2005/04/15 12:31:24 mcorino Exp
# -*- perl -*-

use lib '../../../bin';
use PerlACE::Run_Test;
use POSIX "sys_wait_h";

$iorfile = PerlACE::LocalFile ("server.ior");
unlink $iorfile;

if (PerlACE::is_vxworks_test()) {
    $SV = new PerlACE::ProcessVX ("server", "-o server.ior");
}
else {
    $SV = new PerlACE::Process ("server", "-o $iorfile");
}
$threads = int (rand() * 6) + 1;
$CL = new PerlACE::Process ("client", "-k file://$iorfile -t $threads");


$SV->Spawn ();

if (PerlACE::waitforfile_timed ($iorfile, 250) == -1) {
    print STDERR "ERROR: cannot find file <$iorfile>\n";
    $SV->Kill (); $SV->TimedWait (1);
    exit 1;
}

local $start_time = time();
local $max_running_time = 360;
local $elapsed = time() - $start_time;
my $p = $SV->{'PROCESS'};

while (($elapsed < $max_running_time) ) 
{
 # Start all clients in parallel
  $client = $CL->Spawn ();

  $CL->WaitKill(60) unless $client < 0;

  print STDERR "checking server alive\n";
  
  my $pid = waitpid ($SV->{PROCESS}, &WNOHANG);
  
  if ($pid != 0 && $? != -1) 
  {
    $SV->check_return_value ($?);
    $server_died = 1;
    last;
  }            

  $elapsed = time() - $start_time;
  sleep (1);
}

if (!$server_died) {
  $SH = new PerlACE::Process ("shutdown", "-k file://$iorfile");
  my $shutdown = $SH->Spawn();
  $SH->WaitKill(10) unless $shutdown < 0;

  $server = $SV->WaitKill (30);
}

if ($server != 0) {
    print STDERR "ERROR: server returned $server\n";
    $status = 1;
}

unlink $iorfile;

exit $status;
